==> production-demo-20260209_092157.tar.gz: var/www/html/production-demo/var/tmp/twig/b9/b9f8c2f4bd162bbaa887920ca2e5a299.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Exception/FlattenableException.php */
class __TwigTemplate_00551c97abf5cb2ae6ae8bd717334713 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\CoreBundle\\Exception;

abstract class FlattenableException extends \\Exception
{
    /**
     * @return array{'message': string, 'file': string, 'line': int, 'trace': string}
     */
    public function toArray(): array
    {
        return [
            'message' => \$this->getMessage(),
            'file'    => \$this->getFile(),
            'line'    => \$this->getLine(),
            'trace'   => \$this->getTraceAsString(),
        ];
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Exception/FlattenableException.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Exception/FlattenableException.php", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/Exception/FlattenableException.php");
    }
}

==> production-demo-20260210_204327.tar.gz: var/www/html/production-demo/var/tmp/twig/b9/b9f8c2f4bd162bbaa887920ca2e5a299.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Exception/FlattenableException.php */
class __TwigTemplate_00551c97abf5cb2ae6ae8bd717334713 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\CoreBundle\\Exception;

abstract class FlattenableException extends \\Exception
{
    /**
     * @return array{'message': string, 'file': string, 'line': int, 'trace': string}
     */
    public function toArray(): array
    {
        return [
            'message' => \$this->getMessage(),
            'file'    => \$this->getFile(),
            'line'    => \$this->getLine(),
            'trace'   => \$this->getTraceAsString(),
        ];
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Exception/FlattenableException.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Exception/FlattenableException.php", "/var/www/html/production-demo/app/bundles/CoreBundle/Exception/FlattenableException.php");
    }
}
